@@ -7,7 +7,7 @@
 # it under the terms of version 2 of the GNU General Public License as
 # published by the Free Software Foundation.
 #
-# $Id: __init__.py 3888 2006-10-03 05:58:26Z piman $
+# $Id: __init__.py 3992 2007-01-27 01:40:51Z piman $
 #
 
 """Mutagen aims to be an all purpose tagging library.
@@ -21,7 +21,7 @@ depending on tag or format. They may also be entirely different objects
 for certain keys, again depending on format.
 """
 
-version = (1, 8, -1)
+version = (1, 10, 1)
 version_string = ".".join(map(str, version))
 
 import warnings
@@ -65,6 +65,7 @@ class FileType(mutagen._util.DictMixin):
     info = None
     tags = None
     filename = None
+    _mimes = ["application/octet-stream"]
 
     def __init__(self, filename=None, *args, **kwargs):
         if filename is None:
@@ -135,7 +136,7 @@ class FileType(mutagen._util.DictMixin):
 
     def pprint(self):
         """Print stream information and comment key=value pairs."""
-        stream = self.info.pprint()
+        stream = "%s (%s)" % (self.info.pprint(), self.mime[0])
         try: tags = self.tags.pprint()
         except AttributeError:
             return stream
@@ -144,6 +145,16 @@ class FileType(mutagen._util.DictMixin):
     def add_tags(self):
         raise NotImplementedError
 
+    def __get_mime(self):
+        mimes = []
+        for Kind in type(self).__mro__:
+            for mime in getattr(Kind, '_mimes', []):
+                if mime not in mimes:
+                    mimes.append(mime)
+        return mimes
+
+    mime = property(__get_mime)
+
 def File(filename, options=None):
     """Guess the type of the file and try to open it.
 
@@ -155,6 +166,7 @@ def File(filename, options=None):
     """
 
     if options is None:
+        from mutagen.asf import ASF
         from mutagen.apev2 import APEv2File
         from mutagen.flac import FLAC
         from mutagen.id3 import ID3FileType
@@ -165,12 +177,13 @@ def File(filename, options=None):
         from mutagen.oggvorbis import OggVorbis
         from mutagen.trueaudio import TrueAudio
         from mutagen.wavpack import WavPack
-        from mutagen.m4a import M4A
+        from mutagen.mp4 import MP4
         from mutagen.musepack import Musepack
         from mutagen.monkeysaudio import MonkeysAudio
+        from mutagen.optimfrog import OptimFROG
         options = [MP3, TrueAudio, OggTheora, OggSpeex, OggVorbis, OggFLAC,
-                   FLAC, APEv2File, M4A, ID3FileType, WavPack, Musepack,
-                   MonkeysAudio]
+                   FLAC, APEv2File, MP4, ID3FileType, WavPack, Musepack,
+                   MonkeysAudio, OptimFROG, ASF]
 
     if not options:
         return None
