@@ -5,7 +5,7 @@
 # it under the terms of version 2 of the GNU General Public License as
 # published by the Free Software Foundation.
 #
-# $Id: id3.py 3888 2006-10-03 05:58:26Z piman $
+# $Id: id3.py 3992 2007-01-27 01:40:51Z piman $
 
 """ID3v2 reading and writing.
 
@@ -253,6 +253,10 @@ class ID3(mutagen.Metadata):
         return BitPaddedInt
 
     def __read_frames(self, data, frames):
+        if self.version < (2,4,0) and self.f_unsynch:
+            try: data = unsynch.decode(data)
+            except ValueError: pass
+
         if (2,3,0) <= self.version:
             bpi = self.__determine_bpi(data, frames)
             while data:
@@ -291,10 +295,6 @@ class ID3(mutagen.Metadata):
                     except ID3JunkFrameError: pass
 
     def __load_framedata(self, tag, flags, framedata):
-        if self.f_unsynch or flags & 0x40:
-            try: framedata = unsynch.decode(framedata)
-            except ValueError: pass
-            flags &= ~0x40
         return tag.fromData(self, flags, framedata)
             
     f_unsynch = property(lambda s: bool(s.__flags & 0x80))
@@ -398,7 +398,7 @@ class ID3(mutagen.Metadata):
         framedata = frame._writeData()
         usize = len(framedata)
         if usize > 2048:
-            framedata = pack('>L', usize) + framedata.encode('zlib')
+            framedata = BitPaddedInt.to_str(usize) + framedata.encode('zlib')
             flags |= Frame.FLAG24_COMPRESS | Frame.FLAG24_DATALEN
         datasize = BitPaddedInt.to_str(len(framedata), width=4)
         header = pack('>4s4sH', type(frame).__name__, datasize, flags)
@@ -626,11 +626,14 @@ class BinaryDataSpec(Spec):
     def validate(self, frame, value): return str(value)
 
 class EncodedTextSpec(Spec):
-    encodings = [ ('latin1', '\x00'), ('utf16', '\x00\x00'),
-                  ('utf_16_be', '\x00\x00'), ('utf8', '\x00') ]
+    # Okay, seriously. This is private and defined explicitly and
+    # completely by the ID3 specification. You can't just add
+    # encodings here however you want.
+    _encodings = ( ('latin1', '\x00'), ('utf16', '\x00\x00'),
+                   ('utf_16_be', '\x00\x00'), ('utf8', '\x00') )
 
     def read(self, frame, data):
-        enc, term = self.encodings[frame.encoding]
+        enc, term = self._encodings[frame.encoding]
         ret = ''
         if len(term) == 1:
             if term in data:
@@ -648,7 +651,7 @@ class EncodedTextSpec(Spec):
         return data.decode(enc), ret
 
     def write(self, frame, value):
-        enc, term = self.encodings[frame.encoding]
+        enc, term = self._encodings[frame.encoding]
         return value.encode(enc) + term
 
     def validate(self, frame, value): return unicode(value)
@@ -798,7 +801,7 @@ class VolumePeakSpec(Spec):
 class SynchronizedTextSpec(EncodedTextSpec):
     def read(self, frame, data):
         texts = []
-        encoding, term = self.encodings[frame.encoding]
+        encoding, term = self._encodings[frame.encoding]
         while data:
             l = len(term)
             value_idx = data.index(term)
@@ -810,7 +813,7 @@ class SynchronizedTextSpec(EncodedTextSpec):
 
     def write(self, frame, value):
         data = []
-        encoding, term = self.encodings[frame.encoding]
+        encoding, term = self._encodings[frame.encoding]
         for text, time in frame.text:
             text = text.encode(encoding) + term
             data.append(text + struct.pack(">I", time))
@@ -968,9 +971,13 @@ class Frame(object):
 
         if (2,4,0) <= id3.version:
             if tflags & (Frame.FLAG24_COMPRESS | Frame.FLAG24_DATALEN):
-                usize, = unpack('>L', data[:4])
+                # The data length int is syncsafe in 2.4 (but not 2.3).
+                # However, we don't actually need the data length int,
+                # except to work around a QL 0.12 bug, and in that case
+                # all we need are the raw bytes.
+                datalen_bytes = data[:4]
                 data = data[4:]
-            if tflags & Frame.FLAG24_UNSYNCH and not id3.f_unsynch:
+            if tflags & Frame.FLAG24_UNSYNCH or id3.f_unsynch:
                 try: data = unsynch.decode(data)
                 except ValueError, err:
                     if id3.PEDANTIC:
@@ -982,7 +989,7 @@ class Frame(object):
                 except zlibError, err:
                     # the initial mutagen that went out with QL 0.12 did not
                     # write the 4 bytes of uncompressed size. Compensate.
-                    data = pack('>L', usize) + data
+                    data = datalen_bytes + data
                     try: data = data.decode('zlib')
                     except zlibError, err:
                         if id3.PEDANTIC:
@@ -1206,7 +1213,7 @@ class TCON(TextFrame):
 
     def __decode(self, value):
         if isinstance(value, str):
-            enc = EncodedTextSpec.encodings[self.encoding][0]
+            enc = EncodedTextSpec._encodings[self.encoding][0]
             return value.decode(enc)
         else: return value
 
