@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
 #
-# $Id: m4a.py 3888 2006-10-03 05:58:26Z piman $
+# $Id: m4a.py 3992 2007-01-27 01:40:51Z piman $
 
 """Read and write MPEG-4 audio files with iTunes metadata.
 
@@ -36,13 +36,32 @@ class M4AMetadataError(error): pass
 class M4AStreamInfoError(error): pass
 class M4AMetadataValueError(ValueError, M4AMetadataError): pass
 
+import warnings
+warnings.warn(
+    "mutagen.m4a is deprecated; use mutagen.mp4 instead.", DeprecationWarning)
+
 # This is not an exhaustive list of container atoms, but just the
 # ones this module needs to peek inside.
 _CONTAINERS = ["moov", "udta", "trak", "mdia", "meta", "ilst",
                "stbl", "minf", "stsd"]
 _SKIP_SIZE = { "meta": 4 }
 
-__all__ = ['M4A', 'Open', 'delete']
+__all__ = ['M4A', 'Open', 'delete', 'M4ACover']
+
+class M4ACover(str):
+    """A cover artwork.
+    
+    Attributes:
+    format -- format of the image (either FORMAT_JPEG or FORMAT_PNG)
+    """
+    FORMAT_JPEG = 0x0D
+    FORMAT_PNG = 0x0E
+
+    def __new__(cls, data, format=None):
+        self = str.__new__(cls, data)
+        if format is None: format= M4ACover.FORMAT_JPEG
+        self.format = format
+        return self
 
 class Atom(object):
     """An individual atom.
@@ -162,7 +181,7 @@ class M4ATags(Metadata):
         cpil -- boolean
         trkn, disk -- tuple of 16 bit ints (current, total)
         tmpo -- 16 bit int
-        covr -- raw str data
+        covr -- list of M4ACover objects (which are tagged strs)
         gnre -- not supported. Use '\\xa9gen' instead.
 
     The freeform '----' frames use a key in the format '----:mean:name'
@@ -351,9 +370,18 @@ class M4ATags(Metadata):
         return self.__render_data(key, 0x15, chr(bool(value)))
 
     def __parse_cover(self, atom, data):
-        self[atom.name] = data[16:]
+        length, name, format = struct.unpack(">I4sI", data[:12])
+        if name != "data":
+            raise M4AMetadataError(
+                "unexpected atom %r inside 'covr'" % name)
+        if format not in (M4ACover.FORMAT_JPEG, M4ACover.FORMAT_PNG):
+            format = M4ACover.FORMAT_JPEG
+        self[atom.name]= M4ACover(data[16:length], format)
     def __render_cover(self, key, value):
-        return self.__render_data(key, 0xD, value)
+        try: format = value.format
+        except AttributeError: format = M4ACover.FORMAT_JPEG
+        data = Atom.render("data", struct.pack(">2I", format, 0) + value)
+        return Atom.render(key, data)
 
     def __parse_text(self, atom, data):
         flags = cdata.uint_be(data[8:12])
@@ -434,6 +462,8 @@ class M4A(FileType):
     Only audio ('soun') tracks will be read.
     """
 
+    _mimes = ["audio/mp4", "audio/x-m4a", "audio/mpeg4", "audio/aac"]
+
     def load(self, filename):
         self.filename = filename
         fileobj = file(filename, "rb")
