@@ -16,6 +16,9 @@ class error(RuntimeError): pass
 class HeaderNotFoundError(error, IOError): pass
 class InvalidMPEGHeader(error, IOError): pass
 
+# Mode values.
+STEREO, JOINTSTEREO, DUALCHANNEL, MONO = range(4)
+
 class MPEGInfo(object):
     """MPEG audio stream information
 
@@ -33,6 +36,7 @@ class MPEGInfo(object):
     Useless attributes:
     version -- MPEG version (1, 2, 2.5)
     layer -- 1, 2, or 3
+    mode -- One of STEREO, JOINTSTEREO, DUALCHANNEL, or MONO (0-3)
     protected -- whether or not the file is "protected"
     padding -- whether or not audio frames are padded
     sample_rate -- audio sample rate, in Hz
@@ -121,7 +125,7 @@ class MPEGInfo(object):
                 sample_rate = (frame_data >> 10) & 0x3
                 padding = (frame_data >> 9) & 0x1
                 private = (frame_data >> 8) & 0x1
-                mode = (frame_data >> 6) & 0x3
+                self.mode = (frame_data >> 6) & 0x3
                 mode_extension = (frame_data >> 4) & 0x3
                 copyright = (frame_data >> 3) & 0x1
                 original = (frame_data >> 2) & 0x1
@@ -193,6 +197,8 @@ class MP3(ID3FileType):
     """An MPEG audio (usually MPEG-1 Layer 3) file."""
 
     _Info = MPEGInfo
+    _mimes = ["audio/mp3", "audio/x-mp3", "audio/mpeg", "audio/mpg",
+              "audio/x-mpeg"]
 
     def score(filename, fileobj, header):
         filename = filename.lower()
