@@ -10,9 +10,11 @@ from mutagen.apev2 import APEv2File
 from mutagen.flac import FLAC
 from mutagen.wavpack import WavPack
 from mutagen.trueaudio import TrueAudio
-from mutagen.m4a import M4A
+from mutagen.mp4 import MP4
 from mutagen.musepack import Musepack
 from mutagen.monkeysaudio import MonkeysAudio
+from mutagen.optimfrog import OptimFROG
+from mutagen.asf import ASF
 try: from os.path import devnull
 except ImportError: devnull = "/dev/null"
 
@@ -128,24 +130,42 @@ class TFile(TestCase):
         self.failUnless(isinstance(
             File(os.path.join("tests", "data", "silence-44-s.wv")), WavPack))
 
-    def test_m4a(self):
+    def test_mp4(self):
         self.failUnless(isinstance(
-            File(os.path.join("tests", "data", "has-tags.m4a")), M4A))
+            File(os.path.join("tests", "data", "has-tags.m4a")), MP4))
+        self.failUnless(isinstance(
+            File(os.path.join("tests", "data", "no-tags.m4a")), MP4))
+        self.failUnless(isinstance(
+            File(os.path.join("tests", "data", "no-tags.3g2")), MP4))
+        self.failUnless(isinstance(
+            File(os.path.join("tests", "data", "truncated-64bit.mp4")), MP4))
+
+    def test_optimfrog(self):
+        self.failUnless(isinstance(
+            File(os.path.join("tests", "data", "empty.ofr")), OptimFROG))
+        self.failUnless(isinstance(
+            File(os.path.join("tests", "data", "empty.ofs")), OptimFROG))
+
+    def test_asf(self):
+        self.failUnless(isinstance(
+            File(os.path.join("tests", "data", "silence-1.wma")), ASF))
+        self.failUnless(isinstance(
+            File(os.path.join("tests", "data", "silence-2.wma")), ASF))
+        self.failUnless(isinstance(
+            File(os.path.join("tests", "data", "silence-3.wma")), ASF))
 
 add(TFile)
 
 class TMutagen(TestCase):
     uses_mmap = False
 
-    def test_safe_version(self):
-        from mutagen import version_string
-        path = os.path.join("../../releases/mutagen-%s" % version_string)
-        self.failIf(os.path.isdir(path), "mutagen.version is out of date.")
-
     def test_not_prerelease(self):
         from mutagen import version
         from os.path import dirname, basename, abspath
         trunk = basename(dirname(dirname(dirname(abspath(__file__)))))
         if trunk != "trunk":
             self.failIf(version[-1] < 0, "mutagen.version is a prerelease.")
+        else:
+            self.failIf(
+                version[-1] >= 0, "mutagen.version is not a prerelease.")
 add(TMutagen)
